@@ -4,16 +4,16 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.081 ();
+use IO::Compress::Base::Common 2.086 ();
 
-use IO::Uncompress::Base 2.081 ;
+use IO::Uncompress::Base 2.086 ;
 
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $AnyUncompressError);
 
-$VERSION = '2.081';
+$VERSION = '2.086';
 $AnyUncompressError = '';
 
 @ISA = qw(IO::Uncompress::Base Exporter);
@@ -29,22 +29,31 @@ BEGIN
 {
    local @INC = @INC;
    pop @INC if $INC[-1] eq '.';
-   eval ' use IO::Uncompress::Adapter::Inflate 2.081 ;';
-   eval ' use IO::Uncompress::Adapter::Bunzip2 2.081 ;';
-   eval ' use IO::Uncompress::Adapter::LZO 2.081 ;';
-   eval ' use IO::Uncompress::Adapter::Lzf 2.081 ;';
-   eval ' use IO::Uncompress::Adapter::UnLzma 2.081 ;';
-   eval ' use IO::Uncompress::Adapter::UnXz 2.081 ;';
 
-   eval ' use IO::Uncompress::Bunzip2 2.081 ;';
-   eval ' use IO::Uncompress::UnLzop 2.081 ;';
-   eval ' use IO::Uncompress::Gunzip 2.081 ;';
-   eval ' use IO::Uncompress::Inflate 2.081 ;';
-   eval ' use IO::Uncompress::RawInflate 2.081 ;';
-   eval ' use IO::Uncompress::Unzip 2.081 ;';
-   eval ' use IO::Uncompress::UnLzf 2.081 ;';
-   eval ' use IO::Uncompress::UnLzma 2.081 ;';
-   eval ' use IO::Uncompress::UnXz 2.081 ;';
+   # Don't trigger any __DIE__ Hooks.
+   local $SIG{__DIE__};
+
+   eval ' use IO::Uncompress::Adapter::Inflate 2.086 ;';
+   eval ' use IO::Uncompress::Adapter::Bunzip2 2.086 ;';
+   eval ' use IO::Uncompress::Adapter::LZO 2.086 ;';
+   eval ' use IO::Uncompress::Adapter::Lzf 2.086 ;';
+   eval ' use IO::Uncompress::Adapter::UnLzma 2.086 ;';
+   eval ' use IO::Uncompress::Adapter::UnXz 2.086 ;';
+   eval ' use IO::Uncompress::Adapter::UnZstd 2.083 ;';
+   eval ' use IO::Uncompress::Adapter::UnLzip 2.086 ;';
+
+   eval ' use IO::Uncompress::Bunzip2 2.086 ;';
+   eval ' use IO::Uncompress::UnLzop 2.086 ;';
+   eval ' use IO::Uncompress::Gunzip 2.086 ;';
+   eval ' use IO::Uncompress::Inflate 2.086 ;';
+   eval ' use IO::Uncompress::RawInflate 2.086 ;';
+   eval ' use IO::Uncompress::Unzip 2.086 ;';
+   eval ' use IO::Uncompress::UnLzf 2.086 ;';
+   eval ' use IO::Uncompress::UnLzma 2.086 ;';
+   eval ' use IO::Uncompress::UnXz 2.086 ;';
+   eval ' use IO::Uncompress::UnZstd 2.086 ;';
+   eval ' use IO::Uncompress::UnLzip 2.086 ;';
+
 }
 
 sub new
@@ -191,6 +200,39 @@ sub mkUncomp
          return 1;
      }
 
+     if (defined $IO::Uncompress::UnZstd::VERSION and
+            $magic = $self->ckMagic('UnZstd')) {
+
+        *$self->{Info} = $self->readHeader($magic)
+            or return undef ;
+
+        my ($obj, $errstr, $errno) = IO::Uncompress::Adapter::Zstd::mkUncompObject();
+
+        return $self->saveErrorString(undef, $errstr, $errno)
+            if ! defined $obj;
+
+        *$self->{Uncomp} = $obj;
+
+         return 1;
+     }
+
+
+     if (defined $IO::Uncompress::UnLzip::VERSION and
+            $magic = $self->ckMagic('UnLzip')) {
+
+        *$self->{Info} = $self->readHeader($magic)
+            or return undef ;
+
+        my ($obj, $errstr, $errno) = IO::Uncompress::Adapter::UnLzip::mkUncompObject(*$self->{Info}{DictSize});
+
+        return $self->saveErrorString(undef, $errstr, $errno)
+            if ! defined $obj;
+
+        *$self->{Uncomp} = $obj;
+
+         return 1;
+     }
+
      return 0 ;
 }
 
@@ -299,6 +341,8 @@ The formats supported are:
 
 =item lzma
 
+=item lzip
+
 =item xz
 
 =back
@@ -452,10 +496,7 @@ This parameter defaults to 0.
 
 =item C<< BinModeOut => 0|1 >>
 
-When writing to a file or filehandle, set C<binmode> before writing to the
-file.
-
-Defaults to 0.
+This option is now a no-op. All files will be written  in binmode.
 
 =item C<< Append => 0|1 >>
 
@@ -1009,7 +1050,7 @@ Same as doing this
 
 =head1 SEE ALSO
 
-L<Compress::Zlib>, L<IO::Compress::Gzip>, L<IO::Uncompress::Gunzip>, L<IO::Compress::Deflate>, L<IO::Uncompress::Inflate>, L<IO::Compress::RawDeflate>, L<IO::Uncompress::RawInflate>, L<IO::Compress::Bzip2>, L<IO::Uncompress::Bunzip2>, L<IO::Compress::Lzma>, L<IO::Uncompress::UnLzma>, L<IO::Compress::Xz>, L<IO::Uncompress::UnXz>, L<IO::Compress::Lzop>, L<IO::Uncompress::UnLzop>, L<IO::Compress::Lzf>, L<IO::Uncompress::UnLzf>, L<IO::Uncompress::AnyInflate>
+L<Compress::Zlib>, L<IO::Compress::Gzip>, L<IO::Uncompress::Gunzip>, L<IO::Compress::Deflate>, L<IO::Uncompress::Inflate>, L<IO::Compress::RawDeflate>, L<IO::Uncompress::RawInflate>, L<IO::Compress::Bzip2>, L<IO::Uncompress::Bunzip2>, L<IO::Compress::Lzma>, L<IO::Uncompress::UnLzma>, L<IO::Compress::Xz>, L<IO::Uncompress::UnXz>, L<IO::Compress::Lzip>, L<IO::Uncompress::UnLzip>, L<IO::Compress::Lzop>, L<IO::Uncompress::UnLzop>, L<IO::Compress::Lzf>, L<IO::Uncompress::UnLzf>, L<IO::Compress::Zstd>, L<IO::Uncompress::UnZstd>, L<IO::Uncompress::AnyInflate>
 
 L<IO::Compress::FAQ|IO::Compress::FAQ>
 
@@ -1027,7 +1068,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2018 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2019 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
