@@ -5,7 +5,7 @@ use strict;
 use vars qw( $VERSION $HTML_RENDER_CLASS $HTML_EXTENSION
  $CSS $JAVASCRIPT $SLEEPY $SEARCH_CLASS @ISA
 );
-$VERSION = '3.35';
+$VERSION = '3.38';
 @ISA = ();  # Yup, we're NOT a subclass of Pod::Simple::HTML!
 
 # TODO: nocontents stylesheets. Strike some of the color variations?
@@ -720,22 +720,21 @@ sub _gen_css_wad {
   }
 
   # Now a few indexless variations:
-  foreach my $variation (
-      'blkbluw', # black_with_blue_on_white
-      'whtpurk', # white_with_purple_on_black
-      'whtgrng', # white_with_green_on_grey
-      'grygrnw', # grey_with_green_on_white
-  ) {
-    my $outname = $variation;
+  for (my ($outfile, $variation) = each %{{
+      blkbluw => 'black_with_blue_on_white',
+      whtpurk => 'white_with_purple_on_black',
+      whtgrng => 'white_with_green_on_grey',
+      grygrnw => 'grey_with_green_on_white',
+  }}) {
     my $this_css = join "\n",
-      "/* This file is autogenerated.  Do not edit.  $outname */\n",
+      "/* This file is autogenerated.  Do not edit.  $outfile */\n",
       "\@import url(\"./_$variation.css\");",
       ".indexgroup { display: none; }",
       "\n",
     ;
-    my $name = $outname;    
+    my $name = $outfile;
     $name =~ tr/-_/  /;
-    $self->add_css( "_$outname.css", 0, $name, 0, 0, \$this_css);
+    $self->add_css( "_$outfile.css", 0, $name, 0, 0, \$this_css);
   }
 
   return;
@@ -1110,12 +1109,15 @@ Example:
 
 =item $batchconv = Pod::Simple::HTMLBatch->new;
 
-This TODO
-
+This creates a new batch converter.  The method doesn't take parameters.
+To change the converter's attributes, use the L<"/ACCESSOR METHODS">
+below.
 
 =item $batchconv->batch_convert( I<indirs>, I<outdir> );
 
-this TODO
+This searches the directories given in I<indirs> and writes
+HTML files for each of these to a corresponding directory
+in I<outdir>.  The directory I<outdir> must exist.
 
 =item $batchconv->batch_convert( undef    , ...);
 
